@@ -3,8 +3,9 @@ package Catalyst::Devel;
 use strict;
 use warnings;
 
-our $VERSION             = '1.14_02';
-our $CATALYST_SCRIPT_GEN = 35;
+our $VERSION             = '1.21_01';
+$VERSION = eval $VERSION;
+our $CATALYST_SCRIPT_GEN = 40;
 
 $VERSION = eval $VERSION;
 
@@ -37,6 +38,12 @@ Catalyst Contributors, see Catalyst.pm
 
 sri: Sebastian Riedel <sri@cpan.org>
 
+=head1 COPYRIGHT
+
+Copyright (c) 2006 - 2009
+the Catalyst::Devel L</AUTHOR>
+as listed above.
+
 =head1 LICENSE
 
 This library is free software. You can redistribute it and/or modify
